@@ -111,7 +111,7 @@ class Name(RockerExtension):
 
     @staticmethod
     def register_arguments(parser, defaults={}):
-        parser.add_argument('--name', default='',
+        parser.add_argument('--name', default=defaults.get('name', ''),
                             help='Name of the container.')
 
 
@@ -217,6 +217,9 @@ class User(RockerExtension):
     def get_snippet(self, cliargs):
         snippet = pkgutil.get_data('rocker', 'templates/%s_snippet.Dockerfile.em' % self.name).decode('utf-8')
         substitutions = self.get_environment_subs()
+        if 'user_override_name' in cliargs and cliargs['user_override_name']:
+            substitutions['name'] = cliargs['user_override_name']
+            substitutions['dir'] = os.path.join('/home/', cliargs['user_override_name'])
         substitutions['home_extension_active'] = True if 'home' in cliargs and cliargs['home'] else False
         return em.expand(snippet, substitutions)
 
@@ -226,6 +229,10 @@ class User(RockerExtension):
             action='store_true',
             default=defaults.get('user', None),
             help="mount the current user's id and run as that user")
+        parser.add_argument('--user-override-name',
+            action='store',
+            default=defaults.get('user-override-username', None),
+            help="override the current user's name")
 
 
 class Environment(RockerExtension):
@@ -273,3 +280,26 @@ class Environment(RockerExtension):
     def check_args_for_activation(cls, cli_args):
         """ Returns true if the arguments indicate that this extension should be activated otherwise false."""
         return True if cli_args.get('env') or cli_args.get('env_file') else False
+
+
+class Privileged(RockerExtension):
+    """Add --privileged to docker arguments."""
+    @staticmethod
+    def get_name():
+        return 'privileged'
+
+    def __init__(self):
+        self.name = Privileged.get_name()
+
+    def get_snippet(self, cli_args):
+        return ''
+
+    def get_docker_args(self, cli_args):
+        return ' --privileged'
+
+    @staticmethod
+    def register_arguments(parser, defaults={}):
+        parser.add_argument(name_to_argument(Privileged.get_name()),
+                            action='store_true',
+                            default=defaults.get(Privileged.get_name(), None),
+                            help="give extended privileges to the container")
