@@ -21,7 +21,7 @@ from .core import docker_build
 
 
 DETECTION_TEMPLATE="""
-FROM python:3-stretch as detector
+FROM python:3-slim-stretch as detector
 # Force the older version of debian for detector.
 # GLIBC is forwards compatible but not necessarily backwards compatible for pyinstaller
 # https://github.com/pyinstaller/pyinstaller/wiki/FAQ#gnulinux
@@ -29,13 +29,15 @@ FROM python:3-stretch as detector
 
 RUN mkdir -p /tmp/distrovenv
 RUN python3 -m venv /tmp/distrovenv
+# patchelf needed for staticx
+# binutils provides objdump needed by pyinstaller
+RUN apt-get update && apt-get install -qy patchelf binutils
 RUN . /tmp/distrovenv/bin/activate && pip install distro pyinstaller==4.0 staticx
-RUN apt-get update && apt-get install patchelf #needed for staticx
 
-RUN echo 'import distro; import sys; output = distro.linux_distribution(); print(output) if output[0] else sys.exit(1)' > /tmp/distrovenv/detect_os.py
+RUN echo 'import distro; import sys; output = (distro.name(), distro.version(), distro.codename()); print(output) if distro.name() else sys.exit(1)' > /tmp/distrovenv/detect_os.py
 RUN . /tmp/distrovenv/bin/activate && pyinstaller --onefile /tmp/distrovenv/detect_os.py
 
-RUN . /tmp/distrovenv/bin/activate && staticx /dist/detect_os /dist/detect_os_static
+RUN . /tmp/distrovenv/bin/activate && staticx /dist/detect_os /dist/detect_os_static && chmod go+xr /dist/detect_os_static
 
 FROM %(image_name)s
 
@@ -52,7 +54,13 @@ def detect_os(image_name, output_callback=None, nocache=False):
         return _detect_os_cache[image_name]
 
     iof = StringIO((DETECTION_TEMPLATE % locals()).encode())
-    image_id = docker_build(fileobj = iof, output_callback=output_callback, nocache=nocache)
+    image_id = docker_build(
+        fileobj=iof,
+        output_callback=output_callback,
+        nocache=nocache,
+        forcerm=True,  # Remove intermediate containers from RUN commands in DETECTION_TEMPLATE
+        tag="rocker:" + f"os_detect_{image_name}".replace(':', '_').replace('/', '_')
+    )
     if not image_id:
         if output_callback:
             output_callback('Failed to build detector image')
